@@ -41,22 +41,40 @@ async def test_site_for_nonfrozen_app(make_runner: Any) -> None:
     platform.system() == "Windows", reason="the test is not valid for Windows"
 )
 async def test_runner_setup_handle_signals(make_runner: Any) -> None:
-    runner = make_runner(handle_signals=True)
-    await runner.setup()
-    assert signal.getsignal(signal.SIGTERM) is not signal.SIG_DFL
-    await runner.cleanup()
-    assert signal.getsignal(signal.SIGTERM) is signal.SIG_DFL
+    # Save the original signal handler
+    original_handler = signal.getsignal(signal.SIGTERM)
+    try:
+        # Set a known state for the signal handler to avoid flaky tests
+        signal.signal(signal.SIGTERM, signal.SIG_DFL)
+
+        runner = make_runner(handle_signals=True)
+        await runner.setup()
+        assert signal.getsignal(signal.SIGTERM) is not signal.SIG_DFL
+        await runner.cleanup()
+        assert signal.getsignal(signal.SIGTERM) is signal.SIG_DFL
+    finally:
+        # Restore original signal handler
+        signal.signal(signal.SIGTERM, original_handler)
 
 
 @pytest.mark.skipif(
     platform.system() == "Windows", reason="the test is not valid for Windows"
 )
 async def test_runner_setup_without_signal_handling(make_runner: Any) -> None:
-    runner = make_runner(handle_signals=False)
-    await runner.setup()
-    assert signal.getsignal(signal.SIGTERM) is signal.SIG_DFL
-    await runner.cleanup()
-    assert signal.getsignal(signal.SIGTERM) is signal.SIG_DFL
+    # Save the original signal handler
+    original_handler = signal.getsignal(signal.SIGTERM)
+    try:
+        # Set a known state for the signal handler to avoid flaky tests
+        signal.signal(signal.SIGTERM, signal.SIG_DFL)
+
+        runner = make_runner(handle_signals=False)
+        await runner.setup()
+        assert signal.getsignal(signal.SIGTERM) is signal.SIG_DFL
+        await runner.cleanup()
+        assert signal.getsignal(signal.SIGTERM) is signal.SIG_DFL
+    finally:
+        # Restore original signal handler
+        signal.signal(signal.SIGTERM, original_handler)
 
 
 async def test_site_double_added(make_runner: Any) -> None:
